/*------------------------------------------------------------------------------
--  This file is a part of the libuc, microcontroler library
--  Copyright (C) 2011, Alexis Jeandet
--
--  This program is free software; you can redistribute it and/or modify
--  it under the terms of the GNU General Public License as published by
--  the Free Software Foundation; either version 3 of the License, or
--  (at your option) any later version.
--
--  This program is distributed in the hope that it will be useful,
--  but WITHOUT ANY WARRANTY; without even the implied warranty of
--  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
--  GNU General Public License for more details.
--
--  You should have received a copy of the GNU General Public License
--  along with this program; if not, write to the Free Software
--  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA 
-------------------------------------------------------------------------------
--                 Author : Alexis Jeandet
--                   Mail : alexis.jeandet@gmail.com
-------------------------------------------------------------------------------*/
#ifndef INA226_H
#define INA226_H

#include <i2c.h>
#include <uhandle.h>

typedef struct INA226_t
{
 i2c_t i2cdev;
 uint8_t devAddress;
 uint32_t shuntmOhm;
 uint32_t CurrentRangeuAmp;
}INA226_t;

extern int ina226open(INA226_t* dev,i2c_t i2cdev,uint8_t A0,uint8_t A1,uint32_t shuntmOhm, uint32_t CurrentRangeuAmp);
extern uint8_t ina226getID(INA226_t* dev);
extern int ina226calibrate(INA226_t* dev,uint32_t shuntmOhm, uint32_t CurrentRangeuAmp);
extern uint32_t ina226getBusVoltage(INA226_t* dev);
extern uint32_t ina226getPower(INA226_t* dev);


#define INA226_I2C_ADDRESS 0x40


#define INA226_Die_ID_Reg         0xFF
#define INA226_Shunt_Voltage_Reg  1
#define INA226_Bus_Voltage_Reg    2
#define INA226_Power_Reg          3
#define INA226_Current_Reg        4
#define INA226_Calibration_Reg    5
#define INA226_Mask_Enable_Reg    6
#define INA226_Alert_Limit_Reg    7

#endif







